@@ -45,10 +45,10 @@ class MicroprotocolStatisticsContingencyVertical(Microprotocol):
             self.inverted[value].append(key)
 
         if self.network.myself == 0:
-            self.network.broadcast(self.inverted.keys(), 'keysx')
+            self.network.broadcast(list(self.inverted.keys()), 'keysx')
 
         if self.network.myself == 1:
-            self.network.broadcast(self.inverted.keys(), 'keysy')
+            self.network.broadcast(list(self.inverted.keys()), 'keysy')
 
         return 1, None
 
