@@ -54,14 +54,14 @@ class MicroserviceSimon:
             self._the_cache.append({'task_id': callback, 'body': body})
         return None
 
-    def compute(self, microprotocol, data, network, uuid):
+    def compute(self, microprotocol, data, network):
         sync_api = SyncApi(network['nodes'][0])
         if network['myself'] == 0:
             task = self.create_task(microprotocol, network)
             invitation = task.invite()
-            sync_api.send_broadcast(invitation, uuid)
+            sync_api.send_broadcast(invitation, network['uuid'])
         else:
-            invitation = sync_api.wait_for_broadcast(uuid)
+            invitation = sync_api.wait_for_broadcast(network['uuid'])
             task = self.join_task(invitation, network)
         task.input(data)
         task.start()
